@@ -332,10 +332,10 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 	/* コピー開始 */
 	if((src_size_local > 0) && (open_dst == true))
 	{
-		static md5_state_t state;
-		static md5_byte_t digest[16];
-		static struct verify_data thread_argument;
-		static pthread_t t_verify;
+		md5_state_t state;
+		md5_byte_t digest[16];
+		struct verify_data thread_argument;
+		pthread_t t_verify;
 
 		digest[0] = '\0';
 
@@ -400,6 +400,22 @@ void read_write(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 		{
 			print_error("ftruncate", __FILE__, __LINE__, cpdd);
 		}
+
+		if(verify_option == true)
+		{
+			md5_state_t state_local;
+			md5_state_t *state = &state_local;
+			md5_byte_t digest[16];
+			md5_byte_t buffer[1];
+			digest[0] = '\0';
+			buffer[0] = '\0';
+
+			md5_init(state);
+
+			md5_append(state, buffer, 0);
+
+			MD5_FINISH
+		}
 	}
 
 	if((stat_src == true) && (open_dst == true))
