@@ -18,11 +18,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 
-#include <unistd.h>
-
-/* 関数プロトタイプ */
-static inline void delete_src(const VList *file_list, CPDD *cpdd);
-
 /*******************************************************************************
 *******************************************************************************/
 int main(int argc, char **argv)
@@ -90,12 +85,6 @@ int main(int argc, char **argv)
 		fflush(stdout);
 	}
 
-	/* ファイルとリンクはコピー直後もしくはベリファイ直後に削除しているので、チェックするのはフォルダだけでよい。 */
-	if((oparg->M == MOVE) && (oparg->CHECK_MODE == AFTER) && (cpdd->dir_count > 0))
-	{
-		delete_src(file_list, cpdd);
-	}
-
 	puts("");
 
 	if(cpdd->file_count > 0)
@@ -130,48 +119,3 @@ int main(int argc, char **argv)
 
 	return EXIT_SUCCESS;
 }
-
-/*******************************************************************************
-*******************************************************************************/
-#include <unistd.h>
-
-/*******************************************************************************
-*******************************************************************************/
-static inline void delete_src(const VList *file_list, CPDD *cpdd)
-{
-	/*
-	 * キャストしないと警告が出る
-	 * warning: initialization discards qualifiers from pointer target type
-	 */
-	VList *tmp = (VList *)file_list;
-	tmp = tmp->tail;
-
-	for(;;)
-	{
-		CPInfo *cpinfo = (CPInfo *)tmp->data;
-
-		switch(cpinfo->src_type)
-		{
-		case DIRECTORY:
-			REMOVE_SOURCE_RMDIR
-			break;
-
-		case SYMBOLICLINK:
-			break;
-
-		case REGULAR:
-			break;
-
-		default:
-			fprintf(stderr, "ファイルタイプが不正です\n");
-			break;
-		}
-
-		if(tmp->prev == NULL)
-		{
-			break;
-		}
-
-		tmp = tmp->prev;
-	}
-}
